# Pymablock authors

## Current pymablock maintainers
- Isidora Araya Day
- Anton Akhmerov
- Sebastian Miles

## Other contributors
- Daniel Varjas
- Rafał Skolasinski
- Pablo Pérez Piskunow
- Kostas Vilkelis
- Antonio Manesco
